"""Add program table

Revision ID: 6253c78c6b3a
Revises: f8ac7b4c05a9
Create Date: 2023-10-21 06:05:51.415397

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "6253c78c6b3a"
down_revision = "f8ac7b4c05a9"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.execute(sa.schema.CreateSequence(sa.Sequence("program_program_id_seq")))
    op.create_table(
        "program",
        sa.Column(
            "program_id",
            sa.Integer(),
            server_default=sa.text("nextval('program_program_id_seq')"),
            nullable=False,
            comment="Serial program ID.",
        ),
        sa.Column(
            "name",
            sa.String(length=100),
            nullable=False,
            comment="Program Name.",
        ),
        sa.Column(
            "credential",
            sa.String(length=100),
            nullable=False,
            comment="Program Credential.",
        ),
        sa.Column(
            "url",
            sa.String(length=2083),
            nullable=False,
            comment="BCIT Program URL.",
        ),
        sa.Column(
            "created_at",
            sa.TIMESTAMP(timezone=True),
            server_default=sa.text("now()"),
            nullable=False,
        ),
        sa.Column(
            "updated_at",
            sa.TIMESTAMP(timezone=True),
            server_default=sa.text("now()"),
            nullable=False,
        ),
        sa.Column("deleted_at", sa.TIMESTAMP(timezone=True), nullable=True),
        sa.PrimaryKeyConstraint("program_id", name=op.f("pk_program")),
    )
    op.create_table(
        "program_course_association",
        sa.Column("program_id", sa.Integer(), nullable=True),
        sa.Column("course_id", sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(
            ["course_id"],
            ["course.course_id"],
            name=op.f("fk_program_course_association_course_id_course"),
            ondelete="CASCADE",
        ),
        sa.ForeignKeyConstraint(
            ["program_id"],
            ["program.program_id"],
            name=op.f("fk_program_course_association_program_id_program"),
            ondelete="CASCADE",
        ),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("program_course_association")
    op.drop_table("program")
    op.execute(sa.schema.DropSequence(sa.Sequence("program_program_id_seq")))
    # ### end Alembic commands ###
